---
layout: page
---

<!-- markdownlint-disable MD033 MD041 -->

<script setup>
if (typeof window !== 'undefined') {
  window.location.replace('./ja/')
}
</script>

<meta http-equiv="refresh" content="0;url=./ja/">
